# Default colors
STRONG = "5aa69d"
NEUTRAL = "999999"
POSITIVE = "47b358"
NEGATIVE = "ec6b56"
FILL_BETWEEN = "F7F4F4"
WARM = "ff808f"
COLD = "4062bb"
